import ciw

# https://en.wikipedia.org/wiki/Adversarial_queueing_network
# https://web.mst.edu/~gosavia/queuing_formulas.pdf
# https://en.wikipedia.org/wiki/Retrial_queue
# https://en.wikipedia.org/wiki/Little%27s_law
# https://en.wikipedia.org/wiki/Queuing_Rule_of_Thumb
# https://en.wikipedia.org/wiki/Queueing_theory

class GordonNewellNetwork:
    '''https://en.wikipedia.org/wiki/Gordon%E2%80%93Newell_theorem'''
    def __init__(self):
        raise NotImplementedError

class JacksonNetwork:
    '''https://en.wikipedia.org/wiki/Jackson_network'''
    def __init__(self):
        raise NotImplementedError

class MMcQueue:
    '''https://en.wikipedia.org/wiki/M/M/c_queue'''
    def __init__(self):
        raise NotImplementedError

class BCMPNetwork:
    '''https://en.wikipedia.org/wiki/BCMP_network'''
    def __init__(self):
        raise NotImplementedError

class GelenbeNetwork:
    '''https://en.wikipedia.org/wiki/G-network'''
    def __init__(self):
        raise NotImplementedError

class KellyNetwork:
    '''https://en.wikipedia.org/wiki/Kelly_network'''
    def __init__(self):
        raise NotImplementedError

class DM1Queue:
    '''https://en.wikipedia.org/wiki/D/M/1_queue'''
    def __init__(self):
        raise NotImplementedError

class MD1Queue:
    '''https://en.wikipedia.org/wiki/M/D/1_queue'''
    def __init__(self):
        raise NotImplementedError

class MDCQueue:
    '''https://en.wikipedia.org/wiki/M/D/c_queue'''
    def __init__(self):
        raise NotImplementedError

class MM1Queue:
    '''https://en.wikipedia.org/wiki/M/M/1_queue'''
    def __init__(self):
        raise NotImplementedError    

class MG1Queue:
    '''https://en.wikipedia.org/wiki/M/G/1_queue'''
    def __init__(self):
        raise NotImplementedError

class GM1Queue:
    '''https://en.wikipedia.org/wiki/G/M/1_queue'''
    def __init__(self):
        raise NotImplementedError

class MGkQueue:
    '''https://en.wikipedia.org/wiki/M/G/k_queue'''
    def __init__(self):
        raise NotImplementedError

class GG1Queue:
    '''https://en.wikipedia.org/wiki/G/G/1_queue'''
    def __init__(self):
        raise NotImplementedError

class ForkJoinQueue:
    '''https://en.wikipedia.org/wiki/Fork%E2%80%93join_queue'''
    def __init__(self):
        raise NotImplementedError

class BulkQueue:
    '''https://en.wikipedia.org/wiki/Bulk_queue'''
    def __init__(self):
        raise NotImplementedError
